@@ -14,15 +14,15 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
-#if !data_in_h
-#define data_in_h 1
+#ifndef DATA_DATA_IN_H
+#define DATA_DATA_IN_H 1
 
-#include <stddef.h>
 #include <stdbool.h>
+#include <data/format.h>
+#include <libpspp/legacy-encoding.h>
 #include <libpspp/float-format.h>
 #include <libpspp/integer-format.h>
 #include <libpspp/str.h>
-#include "format.h"
 
 enum integer_format data_in_get_integer_format (void);
 void data_in_set_integer_format (enum integer_format);
@@ -30,8 +30,9 @@ void data_in_set_integer_format (enum integer_format);
 enum float_format data_in_get_float_format (void);
 void data_in_set_float_format (enum float_format);
 
-bool data_in (struct substring input,
+union value;
+bool data_in (struct substring input, enum legacy_encoding,
               enum fmt_type, int implied_decimals, int first_column,
               union value *output, int width);
 
-#endif /* data-in.h */
+#endif /* data/data-in.h */
