@@ -14,18 +14,132 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
-#ifndef DICTIONARY_H
-#define DICTIONARY_H
+#ifndef DATA_DICTIONARY_H
+#define DATA_DICTIONARY_H 1
 
 #include <stdbool.h>
 #include <stddef.h>
+#include <data/case.h>
+#include <data/dict-class.h>
 
-/* Dictionary. */
-
-struct variable;
-struct dictionary;
 struct string;
+struct ccase;
 
+/* Creating dictionaries. */
+struct dictionary *dict_create (void);
+struct dictionary *dict_clone (const struct dictionary *);
+
+
+/* Clearing and destroying dictionaries. */
+void dict_clear (struct dictionary *);
+void dict_clear_aux (struct dictionary *);
+void dict_destroy (struct dictionary *);
+
+/* Common ways to access variables. */
+struct variable *dict_lookup_var (const struct dictionary *, const char *);
+struct variable *dict_lookup_var_assert (const struct dictionary *,
+                                         const char *);
+struct variable *dict_get_var (const struct dictionary *, size_t position);
+size_t dict_get_var_cnt (const struct dictionary *);
+
+/* Other access to variables. */
+bool dict_contains_var (const struct dictionary *, const struct variable *);
+void dict_get_vars (const struct dictionary *,
+                    const struct variable ***vars, size_t *cnt,
+                    enum dict_class exclude);
+void dict_get_vars_mutable (const struct dictionary *,
+                            struct variable ***vars, size_t *cnt,
+                            enum dict_class exclude);
+
+/* Creating variables. */
+struct variable *dict_create_var (struct dictionary *, const char *,
+                                  int width);
+struct variable *dict_create_var_assert (struct dictionary *, const char *,
+                                         int width);
+struct variable *dict_clone_var (struct dictionary *, const struct variable *,
+                                 const char *);
+struct variable *dict_clone_var_assert (struct dictionary *,
+                                        const struct variable *, const char *);
+
+/* Deleting variables. */
+void dict_delete_var (struct dictionary *, struct variable *);
+void dict_delete_vars (struct dictionary *,
+                       struct variable *const *, size_t count);
+void dict_delete_consecutive_vars (struct dictionary *,
+                                   size_t idx, size_t count);
+void dict_delete_scratch_vars (struct dictionary *);
+
+/* Changing the order of variables. */
+void dict_reorder_var (struct dictionary *, struct variable *,
+                       size_t new_index);
+void dict_reorder_vars (struct dictionary *,
+                        struct variable *const *, size_t count);
+
+/* Changing variable names. */
+void dict_rename_var (struct dictionary *, struct variable *, const char *);
+bool dict_rename_vars (struct dictionary *,
+                       struct variable **, char **new_names,
+                       size_t count, char **err_name);
+
+/* Weight variable. */
+double dict_get_case_weight (const struct dictionary *,
+			     const struct ccase *, bool *);
+struct variable *dict_get_weight (const struct dictionary *);
+void dict_set_weight (struct dictionary *, struct variable *);
+
+/* Filter variable. */
+struct variable *dict_get_filter (const struct dictionary *);
+void dict_set_filter (struct dictionary *, struct variable *);
+
+/* Case limit (N OF CASES). */
+casenumber dict_get_case_limit (const struct dictionary *);
+void dict_set_case_limit (struct dictionary *, casenumber);
+
+/* Size of cases for this dictionary. */
+int dict_get_next_value_idx (const struct dictionary *);
+size_t dict_get_case_size (const struct dictionary *);
+
+/* Making this dictionary's cases smaller (if some variables were
+   deleted). */
+size_t dict_count_values (const struct dictionary *,
+                          unsigned int exclude_classes);
+void dict_compact_values (struct dictionary *);
+
+/* SPLIT FILE variables. */
+const struct variable *const *dict_get_split_vars (const struct dictionary *);
+size_t dict_get_split_cnt (const struct dictionary *);
+void dict_set_split_vars (struct dictionary *,
+                          struct variable *const *, size_t cnt);
+void dict_unset_split_var (struct dictionary *, struct variable *);
+
+/* File label. */
+const char *dict_get_label (const struct dictionary *);
+void dict_set_label (struct dictionary *, const char *);
+
+/* Documents. */
+#define DOC_LINE_LENGTH 80 /* Fixed length of document lines. */
+
+const char *dict_get_documents (const struct dictionary *);
+void dict_set_documents (struct dictionary *, const char *);
+void dict_clear_documents (struct dictionary *);
+
+void dict_add_document_line (struct dictionary *, const char *);
+size_t dict_get_document_line_cnt (const struct dictionary *);
+void dict_get_document_line (const struct dictionary *,
+                             size_t, struct string *);
+
+/* Vectors. */
+bool dict_create_vector (struct dictionary *, const char *name,
+                         struct variable **, size_t cnt);
+void dict_create_vector_assert (struct dictionary *, const char *name,
+                                struct variable **, size_t cnt);
+const struct vector *dict_get_vector (const struct dictionary *, size_t idx);
+size_t dict_get_vector_cnt (const struct dictionary *);
+const struct vector *dict_lookup_vector (const struct dictionary *,
+                                         const char *name);
+void dict_clear_vectors (struct dictionary *);
+
+/* Functions to be called upon dictionary changes. */
 struct dict_callbacks
  {
   void (*var_added) (struct dictionary *, int, void *);
@@ -37,109 +151,11 @@ struct dict_callbacks
   void (*split_changed) (struct dictionary *, void *);
  };
 
-
-struct dictionary *dict_create (void);
-struct dictionary *dict_clone (const struct dictionary *);
 void dict_set_callbacks (struct dictionary *, const struct dict_callbacks *,
 			 void *);
 void dict_copy_callbacks (struct dictionary *, const struct dictionary *);
 
-
-void dict_clear (struct dictionary *);
-void dict_clear_aux (struct dictionary *);
-void dict_destroy (struct dictionary *);
-
-size_t dict_get_var_cnt (const struct dictionary *);
-struct variable *dict_get_var (const struct dictionary *, size_t idx);
-inline void dict_get_vars (const struct dictionary *,
-                    const struct variable ***vars, size_t *cnt,
-                    unsigned exclude_classes);
-void dict_get_vars_mutable (const struct dictionary *,
-                    struct variable ***vars, size_t *cnt,
-                    unsigned exclude_classes);
-
-struct variable *dict_create_var (struct dictionary *, const char *,
-                                  int width);
-
-struct variable *dict_create_var_assert (struct dictionary *, const char *,
-                                  int width);
-struct variable *dict_clone_var (struct dictionary *, const struct variable *,
-                                 const char *);
-struct variable *dict_clone_var_assert (struct dictionary *,
-                                        const struct variable *, const char *);
-
-struct variable *dict_lookup_var (const struct dictionary *, const char *);
-struct variable *dict_lookup_var_assert (const struct dictionary *,
-                                         const char *);
-bool dict_contains_var (const struct dictionary *, const struct variable *);
-void dict_delete_var (struct dictionary *, struct variable *);
-void dict_delete_vars (struct dictionary *,
-                       struct variable *const *, size_t count);
-void dict_delete_consecutive_vars (struct dictionary *d,
-                                   size_t idx, size_t count);
-void dict_delete_scratch_vars (struct dictionary *);
-void dict_reorder_var (struct dictionary *d, struct variable *v,
-                       size_t new_index);
-void dict_reorder_vars (struct dictionary *,
-                        struct variable *const *, size_t count);
-void dict_rename_var (struct dictionary *, struct variable *, const char *);
-bool dict_rename_vars (struct dictionary *,
-                       struct variable **, char **new_names,
-                       size_t count, char **err_name);
-
-struct ccase;
-struct variable *dict_get_weight (const struct dictionary *);
-double dict_get_case_weight (const struct dictionary *,
-			     const struct ccase *, bool *);
-void dict_set_weight (struct dictionary *, struct variable *);
-
-struct variable *dict_get_filter (const struct dictionary *);
-void dict_set_filter (struct dictionary *, struct variable *);
-
-size_t dict_get_case_limit (const struct dictionary *);
-void dict_set_case_limit (struct dictionary *, size_t);
-
-int dict_get_next_value_idx (const struct dictionary *);
-size_t dict_get_case_size (const struct dictionary *);
-
-size_t dict_count_values (const struct dictionary *,
-                          unsigned int exclude_classes);
-void dict_compact_values (struct dictionary *);
-
-const struct variable *const *dict_get_split_vars (const struct dictionary *);
-size_t dict_get_split_cnt (const struct dictionary *);
-void dict_set_split_vars (struct dictionary *,
-                          struct variable *const *, size_t cnt);
-void dict_unset_split_var (struct dictionary *d,
-			   struct variable *v);
-
-const char *dict_get_label (const struct dictionary *);
-void dict_set_label (struct dictionary *, const char *);
-
-/* Fixed length of lines in dictionary documents. */
-#define DOC_LINE_LENGTH 80
-
-const char *dict_get_documents (const struct dictionary *);
-void dict_set_documents (struct dictionary *, const char *);
-void dict_clear_documents (struct dictionary *);
-void dict_add_document_line (struct dictionary *, const char *);
-size_t dict_get_document_line_cnt (const struct dictionary *);
-void dict_get_document_line (const struct dictionary *,
-                             size_t, struct string *);
-
-bool dict_create_vector (struct dictionary *,
-                         const char *name,
-                         struct variable **, size_t cnt);
-void dict_create_vector_assert (struct dictionary *,
-                                const char *name,
-                                struct variable **, size_t cnt);
-const struct vector *dict_get_vector (const struct dictionary *,
-                                      size_t idx);
-size_t dict_get_vector_cnt (const struct dictionary *);
-const struct vector *dict_lookup_vector (const struct dictionary *,
-                                         const char *name);
-void dict_clear_vectors (struct dictionary *);
-
+/* Debug use only. */
 void dict_dump (const struct dictionary *);
 
-#endif /* dictionary.h */
+#endif /* data/dictionary.h */
