@@ -1244,7 +1244,7 @@ dump_specifier_init (const specifier *spec, const subcommand *sbc)
 
 	    assert (s->value == VAL_INT || s->value == VAL_DBL
                     || s->value == VAL_STRING);
-	    init = (s->value == VAL_INT ? "NOT_LONG"
+	    init = (s->value == VAL_INT ? "LONG_MIN"
                     : s->value == VAL_DBL ? "SYSMIS"
                     : "NULL");
 
@@ -1339,7 +1339,7 @@ dump_vars_init (int persistent)
 		dump (1, "{");
 		dump (0, "int i;");
 		dump (1, "for (i = 0; i < MAXLISTS; ++i)");
-		dump (0, "p->n_%s[i] = NOT_LONG;", st_lower (sbc->name));
+		dump (0, "p->n_%s[i] = LONG_MIN;", st_lower (sbc->name));
 		dump (-2, "}");
 		break;
 
@@ -2073,18 +2073,19 @@ main (int argc, char *argv[])
 	  indent = 0;
 
 	  dump (0, "#include <stdlib.h>");
-	  dump (0, "#include <libpspp/alloc.h>");
 	  dump (0, "#include <libpspp/assertion.h>");
 	  dump (0, "#include <libpspp/message.h>");
 	  dump (0, "#include <language/lexer/lexer.h>");
 	  dump (0, "#include <language/lexer/variable-parser.h>");
           dump (0, "#include <data/settings.h>");
-	  dump (0, "#include <libpspp/magic.h>");
 	  dump (0, "#include <libpspp/str.h>");
           dump (0, "#include <language/lexer/subcommand-list.h>");
 	  dump (0, "#include <data/variable.h>");
 	  dump (0, nullstr);
 
+          dump (0, "#include \"xalloc.h\"");
+	  dump (0, nullstr);
+
           dump (0, "#include \"gettext.h\"");
           dump (0, "#define _(msgid) gettext (msgid)");
 	  dump (0, nullstr);
