@@ -1,21 +1,18 @@
-/*
-    PSPPIRE --- A Graphical User Interface for PSPP
-    Copyright (C) 2004  Free Software Foundation
+/* PSPPIRE - a graphical user interface for PSPP.
+   Copyright (C) 2004  Free Software Foundation
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA. */
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 
 #ifndef __MISC_H__
@@ -29,7 +26,6 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 
-
 /*
    GtkRecentChooserMenu was added in 2.10.0
    but it didn't support GtkRecentFilters until
@@ -59,10 +55,16 @@ void reference_manual (GtkMenuItem *, gpointer);
 struct getl_interface;
 gboolean execute_syntax (struct getl_interface *sss);
 
-
 #define XML_NEW(FILE) \
    glade_xml_new (relocate(PKGDATADIR "/" FILE), NULL, NULL)
 
 
+void marshaller_VOID__INT_INT_INT (GClosure     *closure,
+				   GValue       *return_value,
+				   guint         n_param_values,
+				   const GValue *param_values,
+				   gpointer      invocation_hint,
+				   gpointer      marshal_data);
+
 
 #endif
