@@ -1,5 +1,5 @@
 /* PSPPIRE - a graphical user interface for PSPP.
-   Copyright (C) 2007, 2010, 2011, 2012  Free Software Foundation
+   Copyright (C) 2007  Free Software Foundation
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,21 +15,25 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+
 #include <config.h>
+#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include "oneway-anova-dialog.h"
 #include "psppire-dict.h"
-#include "psppire-var-view.h"
-#include "builder-wrapper.h"
-#include "psppire-data-window.h"
+#include "psppire-var-store.h"
+#include "helper.h"
+#include <gtksheet/gtksheet.h>
+#include "data-editor.h"
 #include "psppire-dialog.h"
 #include "dialog-common.h"
-#include "psppire-acr.h"
-#include "psppire-selector.h"
 #include "dict-display.h"
+#include "psppire-acr.h"
+
+
+#include <language/syntax-string-source.h>
+#include "syntax-editor.h"
 
-#include "executor.h"
-#include "helper.h"
 
 #include "gettext.h"
 #define _(msgid) gettext (msgid)
@@ -118,53 +122,76 @@ refresh (struct oneway_anova_dialog *ow)
 }
 
 
-
 /* Pops up the dialog box */
 void
-oneway_anova_dialog (PsppireDataWindow *de)
+oneway_anova_dialog (GObject *o, gpointer data)
 {
   gint response;
+  struct data_editor *de = data;
+
+  PsppireVarStore *vs;
+
+  GladeXML *xml = XML_NEW ("oneway.glade");
 
   struct oneway_anova_dialog ow;
 
-  GtkBuilder *builder = builder_new ("oneway.ui");
+  GtkSheet *var_sheet =
+    GTK_SHEET (get_widget_assert (de->xml, "variable_sheet"));
 
   GtkWidget *dict_view =
-    get_widget_assert (builder, "oneway-anova-treeview1");
+    get_widget_assert (xml, "oneway-anova-treeview1");
 
   GtkWidget *selector2 =
-    get_widget_assert (builder, "oneway-anova-selector2");
+    get_widget_assert (xml, "oneway-anova-selector2");
+
+  GtkWidget *selector1 =
+    get_widget_assert (xml, "oneway-anova-selector1");
 
   GtkWidget *contrasts_button =
-    get_widget_assert (builder, "contrasts-button");
+    get_widget_assert (xml, "contrasts-button");
 
 
   g_signal_connect_swapped (contrasts_button, "clicked",
 		    G_CALLBACK (run_contrasts_dialog), &ow);
 
 
-  ow.factor_entry = get_widget_assert (builder, "oneway-anova-entry");
+  ow.factor_entry = get_widget_assert (xml, "oneway-anova-entry");
   ow.vars_treeview =
-    get_widget_assert (builder, "oneway-anova-treeview2");
+    get_widget_assert (xml, "oneway-anova-treeview2");
 
   ow.descriptives =
-    GTK_TOGGLE_BUTTON (get_widget_assert (builder, "checkbutton1"));
+    GTK_TOGGLE_BUTTON (get_widget_assert (xml, "checkbutton1"));
 
   ow.homogeneity =
-    GTK_TOGGLE_BUTTON (get_widget_assert (builder, "checkbutton2"));
+    GTK_TOGGLE_BUTTON (get_widget_assert (xml, "checkbutton2"));
 
-  g_object_get (de->data_editor, "dictionary", &ow.dict, NULL);
+  vs = PSPPIRE_VAR_STORE (gtk_sheet_get_model (var_sheet));
+
+  ow.dict = vs->dict;
 
   ow.dialog =
-    GTK_WINDOW (get_widget_assert (builder, "oneway-anova-dialog"));
+    GTK_WINDOW (get_widget_assert (xml, "oneway-anova-dialog"));
 
-  gtk_window_set_transient_for (ow.dialog, GTK_WINDOW (de));
+  gtk_window_set_transient_for (ow.dialog, de->parent.window);
 
-  g_object_set (dict_view, "model", ow.dict, NULL);
+  attach_dictionary_to_treeview (GTK_TREE_VIEW (dict_view),
+				 vs->dict,
+				 GTK_SELECTION_MULTIPLE, NULL);
+
+  set_dest_model (GTK_TREE_VIEW (ow.vars_treeview), vs->dict);
 
 
-  psppire_selector_set_filter_func (PSPPIRE_SELECTOR (selector2),
-				    is_currently_in_entry);
+  psppire_selector_set_subjects (PSPPIRE_SELECTOR (selector1),
+				 dict_view, ow.vars_treeview,
+				 insert_source_row_into_tree_view,
+				 NULL);
+
+
+  psppire_selector_set_subjects (PSPPIRE_SELECTOR (selector2),
+				 dict_view, ow.factor_entry,
+				 insert_source_row_into_entry,
+				 is_currently_in_entry);
+
 
 
   g_signal_connect_swapped (ow.dialog, "refresh", G_CALLBACK (refresh),  &ow);
@@ -177,16 +204,16 @@ oneway_anova_dialog (PsppireDataWindow *de)
 
   {
     struct contrasts_subdialog *cd = &ow.contrasts;
-    GtkEntry *entry = GTK_ENTRY (get_widget_assert (builder, "entry1"));
+    GtkEntry *entry = GTK_ENTRY (get_widget_assert (xml, "entry1"));
 
-    cd->acr = PSPPIRE_ACR (get_widget_assert (builder, "psppire-acr1"));
-    cd->contrasts_dialog = get_widget_assert (builder, "contrasts-dialog");
+    cd->acr = PSPPIRE_ACR (get_widget_assert (xml, "psppire-acr1"));
+    cd->contrasts_dialog = get_widget_assert (xml, "contrasts-dialog");
 
-    cd->next = get_widget_assert (builder, "next-button");
-    cd->prev = get_widget_assert (builder, "prev-button");
-    cd->ctotal = get_widget_assert (builder, "entry2");
+    cd->next = get_widget_assert (xml, "next-button");
+    cd->prev = get_widget_assert (xml, "prev-button");
+    cd->ctotal = get_widget_assert (xml, "entry2");
 
-    cd->stack_label = get_widget_assert (builder, "contrast-stack-label");
+    cd->stack_label = get_widget_assert (xml, "contrast-stack-label");
 
     /* Contrasts */
     ow.contrasts_array = g_array_new (FALSE, FALSE, sizeof (GtkListStore *));
@@ -197,7 +224,7 @@ oneway_anova_dialog (PsppireDataWindow *de)
     psppire_acr_set_entry (cd->acr, entry);
 
     gtk_window_set_transient_for (GTK_WINDOW (cd->contrasts_dialog),
-				  GTK_WINDOW (de));
+				  de->parent.window);
   }
 
   response = psppire_dialog_run (PSPPIRE_DIALOG (ow.dialog));
@@ -205,10 +232,25 @@ oneway_anova_dialog (PsppireDataWindow *de)
   switch (response)
     {
     case GTK_RESPONSE_OK:
-      g_free (execute_syntax_string (de, generate_syntax (&ow)));
+      {
+	gchar *syntax = generate_syntax (&ow);
+	struct getl_interface *sss = create_syntax_string_source (syntax);
+	execute_syntax (sss);
+
+	g_free (syntax);
+      }
       break;
     case PSPPIRE_RESPONSE_PASTE:
-      g_free (paste_syntax_to_window (generate_syntax (&ow)));
+      {
+	gchar *syntax = generate_syntax (&ow);
+
+	struct syntax_editor *se =
+	  (struct syntax_editor *) window_create (WINDOW_SYNTAX, NULL);
+
+	gtk_text_buffer_insert_at_cursor (se->buffer, syntax, -1);
+
+	g_free (syntax);
+      }
       break;
     default:
       break;
@@ -216,7 +258,7 @@ oneway_anova_dialog (PsppireDataWindow *de)
 
   g_array_free (ow.contrasts_array, FALSE);
 
-  g_object_unref (builder);
+  g_object_unref (xml);
 }
 
 
@@ -226,23 +268,22 @@ static gchar * generate_syntax (const struct oneway_anova_dialog *ow)
   gint i;
   gboolean descriptives = gtk_toggle_button_get_active (ow->descriptives);
   gboolean homogeneity = gtk_toggle_button_get_active (ow->homogeneity);
-  struct string dss;
 
-  ds_init_cstr (&dss, "ONEWAY /VARIABLES=");
+  GString *str = g_string_new ("ONEWAY /VARIABLES=");
 
-  psppire_var_view_append_names_str (PSPPIRE_VAR_VIEW (ow->vars_treeview), 0, &dss);
+  append_variable_names (str, ow->dict, GTK_TREE_VIEW (ow->vars_treeview));
 
-  ds_put_cstr (&dss, " BY ");
+  g_string_append (str, " BY ");
 
-  ds_put_cstr (&dss, gtk_entry_get_text (GTK_ENTRY (ow->factor_entry)));
+  g_string_append (str, gtk_entry_get_text (GTK_ENTRY (ow->factor_entry)));
 
   if (descriptives || homogeneity )
     {
-      ds_put_cstr (&dss, "\n\t/STATISTICS=");
+      g_string_append (str, "\n\t/STATISTICS=");
       if (descriptives)
-	ds_put_cstr (&dss, "DESCRIPTIVES ");
+	g_string_append (str, "DESCRIPTIVES ");
       if (homogeneity)
-	ds_put_cstr (&dss, "HOMOGENEITY ");
+	g_string_append (str, "HOMOGENEITY ");
     }
 
   for (i = 0 ; i < ow->contrasts_array->len ; ++i )
@@ -251,7 +292,7 @@ static gchar * generate_syntax (const struct oneway_anova_dialog *ow)
       GtkTreeIter iter;
       gboolean ok;
 
-      ds_put_cstr (&dss, "\n\t/CONTRAST=");
+      g_string_append (str, "\n\t/CONTRAST=");
 
       for (ok = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(ls),
 					       &iter);
@@ -262,14 +303,14 @@ static gchar * generate_syntax (const struct oneway_anova_dialog *ow)
 
 	  gtk_tree_model_get (GTK_TREE_MODEL (ls), &iter, 0, &v, -1);
 
-	  ds_put_c_format (&dss, " %g", v);
+	  g_string_append_printf (str, " %g", v);
 	}
     }
 
-  ds_put_cstr (&dss, ".\n");
+  g_string_append (str, ".\n");
 
-  text = ds_steal_cstr (&dss);
-  ds_destroy (&dss);
+  text = str->str;
+  g_string_free (str, FALSE);
 
   return text;
 }
@@ -330,7 +371,6 @@ list_store_changed (struct contrasts_subdialog *csd)
 }
 
 
-
 /* Copy the contrasts array into the local array */
 static GArray *
 clone_contrasts_array (GArray *src_array)
@@ -343,7 +383,7 @@ clone_contrasts_array (GArray *src_array)
 
   for (i = 0 ; i < src_array->len ; ++i )
     {
-
+      gboolean ok;
       GtkTreeIter src_iter;
       GtkListStore *src = g_array_index (src_array, GtkListStore*, i);
       GtkListStore *dest;
@@ -353,7 +393,21 @@ clone_contrasts_array (GArray *src_array)
 					   &src_iter))
 	continue;
 
-      dest = clone_list_store (src);
+      dest = gtk_list_store_new (1, G_TYPE_DOUBLE);
+
+      for (ok = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(src),
+					       &src_iter);
+ 	   ok;
+	   ok = gtk_tree_model_iter_next (GTK_TREE_MODEL (src), &src_iter))
+	{
+	  gdouble v;
+	  GtkTreeIter dest_iter;
+
+	  gtk_tree_model_get (GTK_TREE_MODEL (src), &src_iter, 0, &v, -1);
+
+	  gtk_list_store_append  (dest, &dest_iter);
+	  gtk_list_store_set (dest, &dest_iter, 0, v, -1);
+	}
 
       g_array_append_val (dest_array, dest);
     }
