@@ -1,5 +1,5 @@
 /* PSPPIRE - a graphical user interface for PSPP.
-   Copyright (C) 2007, 2010, 2011  Free Software Foundation
+   Copyright (C) 2007  Free Software Foundation
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,9 +19,12 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
+#include <gtk/gtksignal.h>
 #include "psppire-hbuttonbox.h"
 #include "psppire-dialog.h"
 
+#include <gtk/gtkbbox.h>
+
 #include <gettext.h>
 
 #define _(msgid) gettext (msgid)
@@ -37,33 +40,7 @@ static void gtk_hbutton_box_size_allocate (GtkWidget      *widget,
 					   GtkAllocation  *allocation);
 
 
-static void
-psppire_hbutton_box_get_preferred_height (GtkWidget *widget,
-                                gint      *minimal_height,
-                                gint      *natural_height)
-{
-  GtkRequisition requisition;
-
-  gtk_hbutton_box_size_request (widget, &requisition);
-
-  *minimal_height = *natural_height = requisition.height;
-}
-
-
-static void
-psppire_hbutton_box_get_preferred_width (GtkWidget *widget,
-                                gint      *minimal_width,
-                                gint      *natural_width)
-{
-  GtkRequisition requisition;
-
-  gtk_hbutton_box_size_request (widget, &requisition);
-
-  *minimal_width = *natural_width = requisition.width;
-}
-
-
-
+static GtkButtonBoxStyle default_layout_style = GTK_BUTTONBOX_EDGE;
 
 GType
 psppire_hbutton_box_get_type (void)
@@ -99,8 +76,7 @@ psppire_hbuttonbox_class_init (PsppireHButtonBoxClass *class)
 
   widget_class = (GtkWidgetClass*) class;
 
-  widget_class->get_preferred_width = psppire_hbutton_box_get_preferred_width;
-  widget_class->get_preferred_height = psppire_hbutton_box_get_preferred_height;
+  widget_class->size_request = gtk_hbutton_box_size_request;
   widget_class->size_allocate = gtk_hbutton_box_size_allocate;
 }
 
@@ -141,8 +117,9 @@ gtk_hbutton_box_size_request (GtkWidget      *widget,
   box = GTK_BOX (widget);
   bbox = GTK_BUTTON_BOX (widget);
 
-  spacing = gtk_box_get_spacing (box);
-  layout = gtk_button_box_get_layout (bbox) ;
+  spacing = box->spacing;
+  layout = bbox->layout_style != GTK_BUTTONBOX_DEFAULT_STYLE
+	  ? bbox->layout_style : default_layout_style;
 
   _psppire_button_box_child_requisition (widget,
                                      &nvis_children,
@@ -163,19 +140,21 @@ gtk_hbutton_box_size_request (GtkWidget      *widget,
       requisition->width =
 	      nvis_children*child_width + ((nvis_children+1)*spacing);
       break;
-    default:
     case GTK_BUTTONBOX_EDGE:
     case GTK_BUTTONBOX_START:
     case GTK_BUTTONBOX_END:
       requisition->width = nvis_children*child_width + ((nvis_children-1)*spacing);
       break;
+    default:
+      g_assert_not_reached();
+      break;
     }
 
     requisition->height = child_height;
   }
 
-  requisition->width += gtk_container_get_border_width (GTK_CONTAINER (box)) * 2;
-  requisition->height += gtk_container_get_border_width (GTK_CONTAINER (box)) * 2;
+  requisition->width += GTK_CONTAINER (box)->border_width * 2;
+  requisition->height += GTK_CONTAINER (box)->border_width * 2;
 }
 
 
@@ -186,6 +165,7 @@ gtk_hbutton_box_size_allocate (GtkWidget     *widget,
 {
   GtkBox *base_box;
   GtkButtonBox *box;
+  GtkBoxChild *child;
   GList *children;
   GtkAllocation child_allocation;
   gint nvis_children;
@@ -203,28 +183,28 @@ gtk_hbutton_box_size_allocate (GtkWidget     *widget,
 
   base_box = GTK_BOX (widget);
   box = GTK_BUTTON_BOX (widget);
-  spacing = gtk_box_get_spacing (base_box);
-  layout = gtk_button_box_get_layout (box) ;
+  spacing = base_box->spacing;
+  layout = box->layout_style != GTK_BUTTONBOX_DEFAULT_STYLE
+	  ? box->layout_style : default_layout_style;
   _psppire_button_box_child_requisition (widget,
                                      &nvis_children,
 				     &n_secondaries,
                                      &child_width,
                                      &child_height);
-  gtk_widget_set_allocation (widget, allocation);
-  width = allocation->width - gtk_container_get_border_width (GTK_CONTAINER (box))*2;
+  widget->allocation = *allocation;
+  width = allocation->width - GTK_CONTAINER (box)->border_width*2;
   switch (layout)
   {
   case GTK_BUTTONBOX_SPREAD:
     childspacing = (width - (nvis_children * child_width)) / (nvis_children + 1);
-    x = allocation->x + gtk_container_get_border_width (GTK_CONTAINER (box)) + childspacing;
+    x = allocation->x + GTK_CONTAINER (box)->border_width + childspacing;
     secondary_x = x + ((nvis_children - n_secondaries) * (child_width + childspacing));
     break;
-  default:
   case GTK_BUTTONBOX_EDGE:
     if (nvis_children >= 2)
       {
 	childspacing = (width - (nvis_children * child_width)) / (nvis_children - 1);
-	x = allocation->x + gtk_container_get_border_width (GTK_CONTAINER (box));
+	x = allocation->x + GTK_CONTAINER (box)->border_width;
 	secondary_x = x + ((nvis_children - n_secondaries) * (child_width + childspacing));
       }
     else
@@ -236,19 +216,22 @@ gtk_hbutton_box_size_allocate (GtkWidget     *widget,
     break;
   case GTK_BUTTONBOX_START:
     childspacing = spacing;
-    x = allocation->x + gtk_container_get_border_width (GTK_CONTAINER (box));
+    x = allocation->x + GTK_CONTAINER (box)->border_width;
     secondary_x = allocation->x + allocation->width
       - child_width * n_secondaries
       - spacing * (n_secondaries - 1)
-      - gtk_container_get_border_width (GTK_CONTAINER (box));
+      - GTK_CONTAINER (box)->border_width;
     break;
   case GTK_BUTTONBOX_END:
     childspacing = spacing;
     x = allocation->x + allocation->width
       - child_width * (nvis_children - n_secondaries)
       - spacing * (nvis_children - n_secondaries - 1)
-      - gtk_container_get_border_width (GTK_CONTAINER (box));
-    secondary_x = allocation->x + gtk_container_get_border_width (GTK_CONTAINER (box));
+      - GTK_CONTAINER (box)->border_width;
+    secondary_x = allocation->x + GTK_CONTAINER (box)->border_width;
+    break;
+  default:
+    g_assert_not_reached();
     break;
   }
 
@@ -256,29 +239,25 @@ gtk_hbutton_box_size_allocate (GtkWidget     *widget,
   y = allocation->y + (allocation->height - child_height) / 2;
   childspace = child_width + childspacing;
 
-  children = gtk_container_get_children (GTK_CONTAINER (box));
+  children = GTK_BOX (box)->children;
 
   while (children)
     {
-      GtkWidget *child = children->data;
+      child = children->data;
       children = children->next;
 
-      if (gtk_widget_get_visible (child))
+      if (GTK_WIDGET_VISIBLE (child->widget))
 	{
-          gboolean is_secondary = FALSE;
-          gtk_container_child_get (GTK_CONTAINER (box), child, "secondary", &is_secondary, NULL);
-
-
 	  child_allocation.width = child_width;
 	  child_allocation.height = child_height;
 	  child_allocation.y = y;
 
-          if (is_secondary)
-            {
+	  if (child->is_secondary)
+	    {
 	      child_allocation.x = secondary_x;
 	      secondary_x += childspace;
 	    }
-          else
+	  else
 	    {
 	      child_allocation.x = x;
 	      x += childspace;
@@ -287,7 +266,7 @@ gtk_hbutton_box_size_allocate (GtkWidget     *widget,
 	  if (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
 	    child_allocation.x = (allocation->x + allocation->width) - (child_allocation.x + child_width - allocation->x);
 
-	  gtk_widget_size_allocate (child, &child_allocation);
+	  gtk_widget_size_allocate (child->widget, &child_allocation);
 	}
     }
 }
