@@ -55,7 +55,7 @@ mkdir -p $TEMPDIR
 cd $TEMPDIR
 
 activity="create program"
-cat > $TEMPDIR/foo.sps <<EOF
+cat > $TESTFILE <<EOF
 INPUT PROGRAM.
 	COMPUTE num = 3.
 END FILE.
@@ -66,7 +66,7 @@ SAVE outfile='$TEMPDIR/temp.sav'.
 EOF
 if [ $? -ne 0 ] ; then no_result ; fi
 
-$SUPERVISOR $PSPP -o raw-ascii $TEMPDIR/foo.sps
+$SUPERVISOR $PSPP --testing-mode $TESTFILE
 if [ $? -ne 0 ] ; then fail; fi
 
 
