@@ -86,7 +86,7 @@ if [ $? -ne 0 ] ; then no_result ; fi
 
 
 activity="run program"
-$SUPERVISOR $PSPP -o raw-ascii $TESTFILE
+$SUPERVISOR $PSPP --testing-mode $TESTFILE
 if [ $? -ne 0 ] ; then no_result ; fi
 
 
@@ -104,8 +104,8 @@ diff  -b $TEMPDIR/pspp.list - <<EOF
 #===========#==#====#==============#========#
 #     INDEP | N|Mean|Std. Deviation|SE. Mean#
 #===========#==#====#==============#========#
-#DEP < 1.514|11|8.00|         2.864|    .863#
-#    >=1.514|11|9.00|         3.821|   1.152#
+#DEP >=1.514|11|9.00|         3.821|   1.152#
+#    <1.514 |11|8.00|         2.864|    .863#
 #===========#==#====#==============#========#
 2.2 T-TEST.  Independent Samples Test
 #==============================#=========#===============================================================================#
